#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 storable-tuple
version:              0.0.3.3
visibility:           public
id:                   storable-tuple-0.0.3.3-9LtBz0Ohzct21FybeuudQd
key:                  storable-tuple-0.0.3.3-9LtBz0Ohzct21FybeuudQd
license:              BSD-3-Clause
maintainer:           Henning Thielemann <storable@henning-thielemann.de>
author:               Henning Thielemann <storable@henning-thielemann.de>
stability:            Experimental
homepage:             http://code.haskell.org/~thielema/storable-tuple/
synopsis:             Storable instance for pairs and triples
description:
    Provides a Storable instance for pair and triple
    which should be binary compatible with C99 and C++.
    The only purpose of this package is to provide a standard location
    for this instance so that other packages needing this instance
    can play nicely together.

category:             Data, Foreign
abi:                  1e80d87dc3355f2435f161286093a5ac
exposed:              True
exposed-modules:      Foreign.Storable.Tuple
import-dirs:          /usr/lib/ghc-8.10.5/site-local/storable-tuple-0.0.3.3
library-dirs:         /usr/lib/ghc-8.10.5/site-local/storable-tuple-0.0.3.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/i386-linux-ghc-8.10.5/storable-tuple-0.0.3.3
hs-libraries:         HSstorable-tuple-0.0.3.3-9LtBz0Ohzct21FybeuudQd
depends:
    base-4.14.2.0 base-orphans-0.8.4-B4zsXTdczgN9mmNUwgnmE3
    storable-record-0.0.5-KdA4N8DBDnc6rS1v9TAhch
    utility-ht-0.0.16-24GowJ9ezK6J2J6n2aO3mj

haddock-interfaces:
    /usr/share/doc/haskell-storable-tuple/html/storable-tuple.haddock

haddock-html:         /usr/share/doc/haskell-storable-tuple/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

